Crate almeida_estimator

Crate almeida_estimator 

Implementation of “Robust Estimation of Camera Motion Using Optical Flow Models”.

The following estimator produces relatively accurate rotation estimates, with no translational output.

This is not a blind reimplementation of the paper - it contains several improvements to the methods used.

Structs

AlmeidaEstimator
Motion estimator built on a research paper titled “Robust Estimation of Camera Motion Using Optical Flow Models”.

Traits

MotionModel